pub struct Packet {
pub msg: Message,
pub sig: Vec<u8>,
}Expand description
Network packets need to be signed so they can be verified
Fields
msg: MessageThe message to sign
sig: Vec<u8>The bytes of the signature
Implementations
Sourceimpl Packet
impl Packet
Sourcepub fn verify(
&self,
signers_public_keys: &PublicKeys,
coordinator_public_key: &PublicKey,
) -> bool
pub fn verify( &self, signers_public_keys: &PublicKeys, coordinator_public_key: &PublicKey, ) -> bool
This function verifies the packet’s signature, returning true if the signature is valid, i.e. is appropriately signed by either the provided coordinator or one of the provided signer public keys